@@ -14,183 +14,188 @@
         <translation>Skygge</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="30"/>
+        <location filename="../../maindialog.ui" line="67"/>
         <source>The blur radius for shadows</source>
         <translation>Sløringsradiusen af skygger</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="40"/>
+        <location filename="../../maindialog.ui" line="77"/>
         <source>The left offset for shadows</source>
         <translation>Den venstre forskydning af skygger</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="54"/>
+        <location filename="../../maindialog.ui" line="91"/>
         <source>The top offset for shadows</source>
         <translation>Den øverste forskydning af skygger</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="68"/>
+        <location filename="../../maindialog.ui" line="105"/>
         <source>The translucency for shadows</source>
         <translation>Gennemsigtigheden af skygger</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="75"/>
+        <location filename="../../maindialog.ui" line="122"/>
         <source>Color of shadow</source>
         <translation>Farve af skygge</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="89"/>
+        <location filename="../../maindialog.ui" line="57"/>
         <source>Fix some weirdness with ARGB windows</source>
         <translation>Ret nogle særheder med ARGB-vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="92"/>
+        <location filename="../../maindialog.ui" line="60"/>
         <source>Zero the part of the shadow&apos;s mask behind the window</source>
         <translation>Nulificér delen af skyggens maske bag vinduet</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="99"/>
+        <location filename="../../maindialog.ui" line="50"/>
         <source>Don&apos;t draw shadows on DND windows</source>
         <translation>Tegn ikke skygger på DND-vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="106"/>
+        <location filename="../../maindialog.ui" line="43"/>
         <source>Avoid drawing shadows on dock/panel windows</source>
         <translation>Undlad at tegne skygger på dok-/panel-vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="113"/>
+        <location filename="../../maindialog.ui" line="36"/>
         <source>Enable client-side shadows on windows</source>
-        <translation>Aktiver klient-side-skygger på vinduer</translation>
+        <translation>Aktivér klient-side-skygger på vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="120"/>
+        <location filename="../../maindialog.ui" line="136"/>
         <source>Avoid drawing shadow on all shaped windows</source>
         <translation>Undlad at tegne skygge på alle formede vinduet</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="138"/>
+        <location filename="../../maindialog.ui" line="143"/>
+        <source>Crop shadows of maximized windows from extended displays</source>
+        <translation>Beskær skygger på maksimerede vinduer fra udvidede skærme</translation>
+    </message>
+    <message>
+        <location filename="../../maindialog.ui" line="151"/>
         <source>Opacity</source>
         <translation>Opacitet</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="147"/>
+        <location filename="../../maindialog.ui" line="160"/>
         <source>The opacity for menus</source>
         <translation>Opacitet for menuer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="154"/>
+        <location filename="../../maindialog.ui" line="167"/>
         <source>Default opacity of inactive windows</source>
         <translation>Standardopacitet for inaktive vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="161"/>
+        <location filename="../../maindialog.ui" line="174"/>
         <source>Default opacity for active windows</source>
         <translation>Standardopacitet for aktive vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="168"/>
+        <location filename="../../maindialog.ui" line="181"/>
         <source>Opacity of window titlebars and borders</source>
         <translation>Opacitet af vinduers titellinjer og kanter</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="175"/>
+        <location filename="../../maindialog.ui" line="188"/>
         <source>XRender backend: Step size for alpha pictures
 (Increasing it may result in less X resource usage)</source>
         <translation>XRender-backend: trinstørrelse til alfa-billeder
 (forøgelse kan resultere i mindre forbrug af X-ressourcer)</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="183"/>
+        <location filename="../../maindialog.ui" line="196"/>
         <source>Dim inactive windows</source>
         <translation>Ton inaktive vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="190"/>
+        <location filename="../../maindialog.ui" line="203"/>
         <source>Do not let dimness adjust based on window opacity</source>
         <translation>Tillad ikke justering af toning baseret på vinduets opacitet</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="197"/>
+        <location filename="../../maindialog.ui" line="210"/>
         <source>Blur background of transparent windows</source>
         <translation>Slør baggrunden af transparente vinduer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="204"/>
+        <location filename="../../maindialog.ui" line="217"/>
         <source>Blur background of opaque windows with transparent frames as well</source>
         <translation>Slør også baggrunden af synlige vinduer med transparente rammer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="211"/>
+        <location filename="../../maindialog.ui" line="224"/>
         <source>Do not let blur radius adjust based on window opacity</source>
         <translation>Tillad ikke justering af sløringsradius baseret på vinduets opacitet</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="279"/>
+        <location filename="../../maindialog.ui" line="292"/>
         <source>Fade</source>
         <translation>Ton</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="285"/>
+        <location filename="../../maindialog.ui" line="298"/>
         <source>Fade windows during opacity changes</source>
         <translation>Ton vinduer under ændring af opacitet</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="292"/>
+        <location filename="../../maindialog.ui" line="305"/>
         <source>The time between steps in a fade in milliseconds</source>
         <translation>Tiden mellem trin i en toning, i millisekunder</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="299"/>
+        <location filename="../../maindialog.ui" line="312"/>
         <source>Opacity change between steps while fading in</source>
         <translation>Ændring af opacitet mellem trin under indtoning</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="306"/>
+        <location filename="../../maindialog.ui" line="319"/>
         <source>Opacity change between steps while fading out</source>
         <translation>Ændring af opacitet mellem trin under udtoning</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="313"/>
+        <location filename="../../maindialog.ui" line="326"/>
         <source>Avoid fade windows in/out when opening/closing</source>
         <translation>Undlad indtoning/udtoning af vinduer ved åbning/lukning</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="356"/>
+        <location filename="../../maindialog.ui" line="369"/>
         <source>Other</source>
         <translation>Anden</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="368"/>
+        <location filename="../../maindialog.ui" line="381"/>
         <source>Rendering backend</source>
-        <translation type="unfinished"></translation>
+        <translation>Renderingsbackend</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="380"/>
+        <location filename="../../maindialog.ui" line="393"/>
         <source>X Render</source>
-        <translation type="unfinished"></translation>
+        <translation>X-render</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="387"/>
+        <location filename="../../maindialog.ui" line="400"/>
         <source>GLX (OpenGL)</source>
-        <translation type="unfinished"></translation>
+        <translation>GLX (OpenGL)</translation>
     </message>
     <message>
         <source>Not implemented yet</source>
         <translation type="vanished">Endnu ikke implementeret</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="403"/>
+        <location filename="../../maindialog.ui" line="416"/>
         <source>About</source>
         <translation>Om</translation>
     </message>
     <message>
-        <location filename="../../maindialog.cpp" line="206"/>
+        <location filename="../../maindialog.cpp" line="209"/>
         <source>About ComptonConf</source>
         <translation>Om ComptonConf</translation>
     </message>
     <message>
-        <location filename="../../maindialog.cpp" line="207"/>
+        <location filename="../../maindialog.cpp" line="210"/>
         <source>ComptonConf - configuration tool for compton
 
 Copyright (C) 2013
