@@ -14,47 +14,47 @@
         <translation>Sombra</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="30"/>
+        <location filename="../../maindialog.ui" line="67"/>
         <source>The blur radius for shadows</source>
         <translation>Raio de desfocagem da sombra</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="40"/>
+        <location filename="../../maindialog.ui" line="77"/>
         <source>The left offset for shadows</source>
         <translation>Desvio da margem esquerda da sombra</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="54"/>
+        <location filename="../../maindialog.ui" line="91"/>
         <source>The top offset for shadows</source>
         <translation>Desvio da margem superior da sombra</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="68"/>
+        <location filename="../../maindialog.ui" line="105"/>
         <source>The translucency for shadows</source>
         <translation>Translucência das janelas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="75"/>
+        <location filename="../../maindialog.ui" line="122"/>
         <source>Color of shadow</source>
         <translation>Cor da sombra</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="89"/>
+        <location filename="../../maindialog.ui" line="57"/>
         <source>Fix some weirdness with ARGB windows</source>
         <translation>Corrigir imperfeições das janelas ARGB</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="92"/>
+        <location filename="../../maindialog.ui" line="60"/>
         <source>Zero the part of the shadow&apos;s mask behind the window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="99"/>
+        <location filename="../../maindialog.ui" line="50"/>
         <source>Don&apos;t draw shadows on DND windows</source>
         <translation>Não criar sombras ao arrastar e largar janelas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="106"/>
+        <location filename="../../maindialog.ui" line="43"/>
         <source>Avoid drawing shadows on dock/panel windows</source>
         <translation>Não criar sombras nas janelas da doca/painel</translation>
     </message>
@@ -63,145 +63,150 @@
         <translation type="vanished">Ativar sombras &quot;client-side&quot; nas janelas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="113"/>
+        <location filename="../../maindialog.ui" line="36"/>
         <source>Enable client-side shadows on windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Ativar sombra &apos;client-side&apos; nas janelas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="120"/>
+        <location filename="../../maindialog.ui" line="136"/>
         <source>Avoid drawing shadow on all shaped windows</source>
         <translation>Não criar sombras nas janelas enroladas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="138"/>
+        <location filename="../../maindialog.ui" line="143"/>
+        <source>Crop shadows of maximized windows from extended displays</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../maindialog.ui" line="151"/>
         <source>Opacity</source>
         <translation>Opacidade</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="147"/>
+        <location filename="../../maindialog.ui" line="160"/>
         <source>The opacity for menus</source>
         <translation>Opacidade dos menus</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="154"/>
+        <location filename="../../maindialog.ui" line="167"/>
         <source>Default opacity of inactive windows</source>
         <translation>Opacidade padrão das janelas inativas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="161"/>
+        <location filename="../../maindialog.ui" line="174"/>
         <source>Default opacity for active windows</source>
         <translation>Opacidade padrão das janelas ativas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="168"/>
+        <location filename="../../maindialog.ui" line="181"/>
         <source>Opacity of window titlebars and borders</source>
         <translation>Opacidade da barra de título e dos contornos</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="175"/>
+        <location filename="../../maindialog.ui" line="188"/>
         <source>XRender backend: Step size for alpha pictures
 (Increasing it may result in less X resource usage)</source>
         <translation>Infraestrutura XRender: etapa para imagens alfa
 (Valores mais altos podem reduzir a utilização do X)</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="183"/>
+        <location filename="../../maindialog.ui" line="196"/>
         <source>Dim inactive windows</source>
         <translation>Escurecimento das janelas inativas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="190"/>
+        <location filename="../../maindialog.ui" line="203"/>
         <source>Do not let dimness adjust based on window opacity</source>
         <translation>Não escurecer tendo como base a opacidade da janela</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="197"/>
+        <location filename="../../maindialog.ui" line="210"/>
         <source>Blur background of transparent windows</source>
         <translation>Desfocar fundo das janelas transparentes</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="204"/>
+        <location filename="../../maindialog.ui" line="217"/>
         <source>Blur background of opaque windows with transparent frames as well</source>
         <translation>Desfocar fundo das janelas opacas com molduras transparentes</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="211"/>
+        <location filename="../../maindialog.ui" line="224"/>
         <source>Do not let blur radius adjust based on window opacity</source>
         <translation>Não ajustar o raio de desfocagem tendo como base a opacidade da janela</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="279"/>
+        <location filename="../../maindialog.ui" line="292"/>
         <source>Fade</source>
         <translation>Desvanecimento</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="285"/>
+        <location filename="../../maindialog.ui" line="298"/>
         <source>Fade windows during opacity changes</source>
         <translation>Desvanecer janelas durante as mudanças de opacidade</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="292"/>
+        <location filename="../../maindialog.ui" line="305"/>
         <source>The time between steps in a fade in milliseconds</source>
         <translation>Duração das etapas de desvanecimento em milissegundos</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="299"/>
+        <location filename="../../maindialog.ui" line="312"/>
         <source>Opacity change between steps while fading in</source>
         <translation>Mudanças de opacidade entre etapas ao aparecer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="306"/>
+        <location filename="../../maindialog.ui" line="319"/>
         <source>Opacity change between steps while fading out</source>
         <translation>Mudanças de opacidade entre etapas ao desaparecer</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="313"/>
+        <location filename="../../maindialog.ui" line="326"/>
         <source>Avoid fade windows in/out when opening/closing</source>
         <translation>Não desvanecer ao abrir e fechar janelas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="356"/>
+        <location filename="../../maindialog.ui" line="369"/>
         <source>Other</source>
         <translation>Outras</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="368"/>
+        <location filename="../../maindialog.ui" line="381"/>
         <source>Rendering backend</source>
-        <translation type="unfinished"></translation>
+        <translation>Renderização</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="380"/>
+        <location filename="../../maindialog.ui" line="393"/>
         <source>X Render</source>
-        <translation type="unfinished"></translation>
+        <translation>X Render</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="387"/>
+        <location filename="../../maindialog.ui" line="400"/>
         <source>GLX (OpenGL)</source>
-        <translation type="unfinished"></translation>
+        <translation>GLX (OpenGL)</translation>
     </message>
     <message>
         <source>Not implemented yet</source>
         <translation type="vanished">Ainda não implementadas</translation>
     </message>
     <message>
-        <location filename="../../maindialog.ui" line="403"/>
+        <location filename="../../maindialog.ui" line="416"/>
         <source>About</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../../maindialog.cpp" line="206"/>
+        <location filename="../../maindialog.cpp" line="209"/>
         <source>About ComptonConf</source>
         <translation>Sobre ComptomConf</translation>
     </message>
     <message>
-        <location filename="../../maindialog.cpp" line="207"/>
+        <location filename="../../maindialog.cpp" line="210"/>
         <source>ComptonConf - configuration tool for compton
 
 Copyright (C) 2013
 Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
         <translation>ComptonConf - ferramenta de configuração para o compton
 
-Copyright (C) 2013-2016
+Copyright (C) 2013-2017
 Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     </message>
 </context>
