@@ -4,73 +4,94 @@
 <context>
     <name>LxImage::Application</name>
     <message>
-        <location filename="../../application.cpp" line="89"/>
+        <location filename="../../application.cpp" line="94"/>
         <source>Take a screenshot</source>
         <translation>Bildschirmfoto erstellen</translation>
     </message>
     <message>
-        <location filename="../../application.cpp" line="93"/>
+        <location filename="../../application.cpp" line="98"/>
         <source>[FILE1, FILE2,...]</source>
         <translation>[Datei1, Datei2,...]</translation>
     </message>
 </context>
+<context>
+    <name>LxImage::ImageShackUpload</name>
+    <message>
+        <location filename="../../upload/imageshackupload.cpp" line="49"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::ImgurUpload</name>
+    <message>
+        <location filename="../../upload/imgurupload.cpp" line="46"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LxImage::MainWindow</name>
     <message>
-        <location filename="../../mainwindow.cpp" line="148"/>
+        <location filename="../../mainwindow.cpp" line="145"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="149"/>
+        <location filename="../../mainwindow.cpp" line="146"/>
         <source>LXImage - a simple and fast image viewer
 
 Copyright (C) 2013
-LXDE Project: http://lxde.org/
+LXQt Project: https://lxqt.org/
 
 Authors:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
         <translation>LXImage - ein einfacher und schneller Bildbetrachter
 
 Copyright (C) 2013
-LXDE Project: http://lxde.org/
+LXQt Project: https://lxqt.org/
 
 Autor:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="242"/>
+        <location filename="../../mainwindow.cpp" line="255"/>
         <source>Open File</source>
         <translation>Datei öffnen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="243"/>
-        <location filename="../../mainwindow.cpp" line="264"/>
+        <location filename="../../mainwindow.cpp" line="256"/>
+        <location filename="../../mainwindow.cpp" line="283"/>
         <source>Image files (%1)</source>
         <translation>Bilddateien (%1)</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="264"/>
+        <location filename="../../mainwindow.cpp" line="262"/>
+        <source>Open directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.cpp" line="283"/>
         <source>Save File</source>
         <translation>Datei speichern</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="530"/>
+        <location filename="../../mainwindow.cpp" line="539"/>
         <source>[*]%1 (Loading...) - Image Viewer</source>
         <translation>[*]%1 (Lade...) - Bildbetrachter</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="535"/>
+        <location filename="../../mainwindow.cpp" line="544"/>
         <source>[*]%1 (Failed to Load) - Image Viewer</source>
         <translation>[*]%1 (Laden ist fehlgeschlagen) - Bildbetrachter</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="539"/>
+        <location filename="../../mainwindow.cpp" line="548"/>
         <source>[*]%1 (%2x%3) - Image Viewer</source>
         <translation>[*]%1 (%2x%3) - Bildbetrachter</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="576"/>
+        <location filename="../../mainwindow.cpp" line="584"/>
         <source>[*]Image Viewer</source>
         <translation>[*]Bildbetrachter</translation>
     </message>
@@ -91,11 +112,44 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <translation type="vanished">Bildbetrachter</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="819"/>
+        <location filename="../../mainwindow.cpp" line="851"/>
         <source>Thumbnails</source>
         <translation>Miniaturen</translation>
     </message>
 </context>
+<context>
+    <name>LxImage::UploadDialog</name>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="47"/>
+        <source>Imgur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="48"/>
+        <source>ImageShack</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="124"/>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="127"/>
+        <source>Stop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="130"/>
+        <source>Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="137"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -104,247 +158,276 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <translation>Bildbetrachter</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="159"/>
+        <location filename="../../mainwindow.ui" line="162"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="169"/>
+        <location filename="../../mainwindow.ui" line="172"/>
         <source>&amp;Open File</source>
         <translatorcomment>This should be &quot;&amp;Open&quot; (without &quot;File&quot;) imho. We are in the File menu.</translatorcomment>
         <translation>Ö&amp;ffnen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="172"/>
+        <location filename="../../mainwindow.ui" line="175"/>
         <source>Ctrl+O</source>
         <translatorcomment>Shortcuts are translated automatically. No need to manually translate it to &quot;Strg+O&quot;.</translatorcomment>
         <translation>Strg+O</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="182"/>
+        <location filename="../../mainwindow.ui" line="185"/>
         <source>&amp;Save</source>
         <translation>&amp;Speichern</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="185"/>
+        <location filename="../../mainwindow.ui" line="188"/>
         <source>Ctrl+S</source>
         <translation>Strg+S</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="195"/>
+        <location filename="../../mainwindow.ui" line="198"/>
         <source>Save &amp;As</source>
         <translation>Speichern &amp;unter</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="198"/>
+        <location filename="../../mainwindow.ui" line="201"/>
         <source>Ctrl+A</source>
         <translation>Strg+A</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="208"/>
+        <location filename="../../mainwindow.ui" line="211"/>
         <source>&amp;Close</source>
         <translation>Sch&amp;ließen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="211"/>
+        <location filename="../../mainwindow.ui" line="214"/>
         <source>Ctrl+W</source>
         <translation>Strg+W</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="221"/>
+        <location filename="../../mainwindow.ui" line="224"/>
         <source>Zoom &amp;In</source>
         <translation>Ver&amp;größern</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="224"/>
         <source>Ctrl++</source>
-        <translation>Strg++</translation>
+        <translation type="vanished">Strg++</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="234"/>
+        <location filename="../../mainwindow.ui" line="237"/>
         <source>Zoom &amp;Out</source>
         <translation>Ver&amp;kleinern</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="237"/>
+        <location filename="../../mainwindow.ui" line="240"/>
         <source>Ctrl+-</source>
         <translation>Strg+-</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="247"/>
+        <location filename="../../mainwindow.ui" line="250"/>
         <source>&amp;Copy to Clipboard</source>
         <translation>In die &amp;Zwischenablage einfügen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="257"/>
         <location filename="../../mainwindow.ui" line="260"/>
+        <location filename="../../mainwindow.ui" line="263"/>
         <source>Next File</source>
         <translation>Nächste Datei</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="273"/>
         <location filename="../../mainwindow.ui" line="276"/>
+        <location filename="../../mainwindow.ui" line="279"/>
         <source>Previous File</source>
         <translation>Vorige Datei</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="263"/>
+        <location filename="../../mainwindow.ui" line="266"/>
         <source>PgDown</source>
         <translation>Bild auf</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="279"/>
+        <location filename="../../mainwindow.ui" line="227"/>
+        <source>Ctrl+=</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="282"/>
         <source>PgUp</source>
         <translation>Bild ab</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="289"/>
+        <location filename="../../mainwindow.ui" line="292"/>
         <source>Original Size</source>
         <translation>Originalgröße</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="299"/>
+        <location filename="../../mainwindow.ui" line="295"/>
+        <source>Ctrl+0</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="305"/>
         <source>&amp;Fit</source>
         <translation>Passen&amp;d</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="309"/>
+        <location filename="../../mainwindow.ui" line="315"/>
         <source>&amp;Rotate Clockwise</source>
         <translation>Im &amp;Uhrzeigersinn drehen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="319"/>
+        <location filename="../../mainwindow.ui" line="325"/>
         <source>Rotate &amp;Counterclockwise</source>
         <translation>&amp;Gegen den Uhrzeigersinn drehen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="324"/>
+        <location filename="../../mainwindow.ui" line="330"/>
         <source>P&amp;references</source>
         <translation>Einste&amp;llungen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="329"/>
+        <location filename="../../mainwindow.ui" line="335"/>
         <source>&amp;Print</source>
         <translation>&amp;Drucken</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="332"/>
+        <location filename="../../mainwindow.ui" line="338"/>
         <source>Ctrl+P</source>
         <translation>Strg+P</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="342"/>
+        <location filename="../../mainwindow.ui" line="348"/>
         <source>First File</source>
         <translation>Erste Datei</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="345"/>
+        <location filename="../../mainwindow.ui" line="351"/>
         <source>Home</source>
         <translation>Pos1</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="355"/>
+        <location filename="../../mainwindow.ui" line="361"/>
         <source>Last File</source>
         <translation>Letzte Datei</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="358"/>
+        <location filename="../../mainwindow.ui" line="364"/>
         <source>End</source>
         <translation>Ende</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="368"/>
+        <location filename="../../mainwindow.ui" line="374"/>
         <source>&amp;New Window</source>
         <translation>&amp;Neues Fenster</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="371"/>
+        <location filename="../../mainwindow.ui" line="377"/>
         <source>Ctrl+N</source>
         <translation>Strg+N</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="376"/>
+        <location filename="../../mainwindow.ui" line="382"/>
         <source>Flip &amp;Horizontally</source>
         <translation>&amp;Horizontal spiegeln</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="386"/>
+        <location filename="../../mainwindow.ui" line="392"/>
         <source>Capture Screenshot</source>
         <translation>Bildschirmfoto erstellen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="394"/>
+        <location filename="../../mainwindow.ui" line="400"/>
         <source>F&amp;ull Screen</source>
         <translation>&amp;Gesamter Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="397"/>
+        <location filename="../../mainwindow.ui" line="403"/>
         <source>F11</source>
         <translation>F11</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="402"/>
+        <location filename="../../mainwindow.ui" line="408"/>
         <source>Flip &amp;Vertically</source>
         <translation>&amp;Vertikal spiegeln</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="412"/>
+        <location filename="../../mainwindow.ui" line="418"/>
         <source>&amp;Paste from Clipboard</source>
         <translation>&amp;Aus Zwischenablage einfügen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="425"/>
+        <location filename="../../mainwindow.ui" line="431"/>
         <source>&amp;Slide Show</source>
         <translation>&amp;Diaschau</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="435"/>
+        <location filename="../../mainwindow.ui" line="441"/>
         <source>&amp;Delete</source>
         <translation>&amp;Löschen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="438"/>
+        <location filename="../../mainwindow.ui" line="444"/>
         <source>Del</source>
         <translation>Entf</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="446"/>
+        <location filename="../../mainwindow.ui" line="452"/>
         <source>Show Thumbnails</source>
         <translation>Miniaturen anzeigen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="451"/>
+        <location filename="../../mainwindow.ui" line="457"/>
         <source>File Properties</source>
         <translatorcomment>Translation of &apos;file&apos; skipped, it is redundant (this is the file menu).</translatorcomment>
         <translation>Eigenschaften</translation>
     </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="465"/>
+        <source>Open &amp;Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="468"/>
+        <source>Ctrl+D</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="476"/>
+        <source>Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="479"/>
+        <source>Upload the image</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../mainwindow.ui" line="55"/>
         <source>&amp;File</source>
         <translation>&amp;Datei</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="71"/>
+        <location filename="../../mainwindow.ui" line="72"/>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="77"/>
+        <location filename="../../mainwindow.ui" line="78"/>
         <source>Go</source>
         <translation>Gehe zu</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="86"/>
+        <location filename="../../mainwindow.ui" line="87"/>
         <source>&amp;View</source>
         <translation>&amp;Ansicht</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="100"/>
+        <location filename="../../mainwindow.ui" line="101"/>
         <source>&amp;Edit</source>
         <translation>&amp;Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="120"/>
+        <location filename="../../mainwindow.ui" line="123"/>
         <source>Toolbar</source>
         <translation>Werkzeugleiste</translation>
     </message>
@@ -390,44 +473,57 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <translation>Bildschirmfoto</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="28"/>
+        <location filename="../../screenshotdialog.ui" line="27"/>
         <source>Take a screenshot</source>
         <translation>Bildschirmfoto erstellen</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="35"/>
+        <location filename="../../screenshotdialog.ui" line="34"/>
         <source>Region</source>
         <translation>Bereich</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="41"/>
+        <location filename="../../screenshotdialog.ui" line="40"/>
         <source>Whole screen</source>
         <translation>Gesamter Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="51"/>
+        <location filename="../../screenshotdialog.ui" line="50"/>
         <source>Current window only</source>
         <translation>Nur aktuelles Fenster</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="61"/>
+        <location filename="../../screenshotdialog.ui" line="57"/>
+        <source>Capture an area of the screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../screenshotdialog.ui" line="67"/>
         <source>Include mouse cursor</source>
         <translation>Einschließlich Mauszeiger</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="68"/>
+        <location filename="../../screenshotdialog.ui" line="74"/>
         <source> seconds</source>
         <translation> Sekunden</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="85"/>
+        <location filename="../../screenshotdialog.ui" line="91"/>
         <source>Delay:</source>
         <translation>Verzögerung:</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="95"/>
+        <location filename="../../screenshotdialog.ui" line="101"/>
         <source>Include window title and frame</source>
         <translation>Einschließlich Fenstertitel und Rahmen</translation>
     </message>
 </context>
+<context>
+    <name>UploadDialog</name>
+    <message>
+        <location filename="../../upload/uploaddialog.ui" line="14"/>
+        <source>Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
