@@ -4,87 +4,136 @@
 <context>
     <name>LxImage::Application</name>
     <message>
-        <location filename="../../application.cpp" line="91"/>
+        <location filename="../../application.cpp" line="94"/>
         <source>Take a screenshot</source>
         <translation>Faire une copie d&apos;écran</translation>
     </message>
     <message>
-        <location filename="../../application.cpp" line="95"/>
+        <location filename="../../application.cpp" line="98"/>
         <source>[FILE1, FILE2,...]</source>
         <translation>[FICHIER1,FICHIER2,...]</translation>
     </message>
 </context>
+<context>
+    <name>LxImage::ImageShackUpload</name>
+    <message>
+        <location filename="../../upload/imageshackupload.cpp" line="49"/>
+        <source>unknown error response</source>
+        <translation>réponse : erreur inconnue</translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::ImgurUpload</name>
+    <message>
+        <location filename="../../upload/imgurupload.cpp" line="46"/>
+        <source>unknown error response</source>
+        <translation>réponse : erreur inconnue</translation>
+    </message>
+</context>
 <context>
     <name>LxImage::MainWindow</name>
     <message>
-        <location filename="../../mainwindow.cpp" line="143"/>
+        <location filename="../../mainwindow.cpp" line="145"/>
         <source>About</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="144"/>
+        <location filename="../../mainwindow.cpp" line="146"/>
         <source>LXImage - a simple and fast image viewer
 
 Copyright (C) 2013
-LXDE Project: http://lxde.org/
+LXQt Project: https://lxqt.org/
 
 Authors:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
         <translation>LXImage - un visionneur d&apos;image simple et rapide
 
 Copyright (C) 2013
-LXDE Project: http://lxde.org/
+LXQt Project: https://lxqt.org/
 
 Auteurs:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="253"/>
+        <location filename="../../mainwindow.cpp" line="255"/>
         <source>Open File</source>
         <translation>Ouvrir un fichier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="254"/>
-        <location filename="../../mainwindow.cpp" line="281"/>
+        <location filename="../../mainwindow.cpp" line="256"/>
+        <location filename="../../mainwindow.cpp" line="283"/>
         <source>Image files (%1)</source>
         <translation>Fichier image (%1)</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="260"/>
+        <location filename="../../mainwindow.cpp" line="262"/>
         <source>Open directory</source>
         <translation>Ouvrir le répertoire</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="281"/>
+        <location filename="../../mainwindow.cpp" line="283"/>
         <source>Save File</source>
         <translation>Enregistrer un fichier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="537"/>
+        <location filename="../../mainwindow.cpp" line="539"/>
         <source>[*]%1 (Loading...) - Image Viewer</source>
         <translation>[*]%1 (Chargement...) - Visionneur d&apos;image</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="542"/>
+        <location filename="../../mainwindow.cpp" line="544"/>
         <source>[*]%1 (Failed to Load) - Image Viewer</source>
         <translation>[*]%1 (Échec de chargement) - Visionneur d&apos;image</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="546"/>
+        <location filename="../../mainwindow.cpp" line="548"/>
         <source>[*]%1 (%2x%3) - Image Viewer</source>
         <translation>[*]%1 (%2x%3) - Visionneur d&apos;image</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="582"/>
+        <location filename="../../mainwindow.cpp" line="584"/>
         <source>[*]Image Viewer</source>
         <translation>[*]Visionneur d&apos;image</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="842"/>
+        <location filename="../../mainwindow.cpp" line="851"/>
         <source>Thumbnails</source>
         <translation>Miniatures</translation>
     </message>
 </context>
+<context>
+    <name>LxImage::UploadDialog</name>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="47"/>
+        <source>Imgur</source>
+        <translation>Imgur</translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="48"/>
+        <source>ImageShack</source>
+        <translation>ImageShack</translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="124"/>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="127"/>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="130"/>
+        <source>Close</source>
+        <translation>Fermer</translation>
+    </message>
+    <message>
+        <location filename="../../upload/uploaddialog.cpp" line="137"/>
+        <source>Error</source>
+        <translation>Erreur</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -118,237 +167,247 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <translation>&amp;Editer</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="121"/>
+        <location filename="../../mainwindow.ui" line="123"/>
         <source>Toolbar</source>
         <translation>Barre des outils</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="160"/>
+        <location filename="../../mainwindow.ui" line="162"/>
         <source>&amp;About</source>
         <translation>À &amp;propos</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="170"/>
+        <location filename="../../mainwindow.ui" line="172"/>
         <source>&amp;Open File</source>
         <translation>&amp;Ouvrir un fichier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="173"/>
+        <location filename="../../mainwindow.ui" line="175"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="183"/>
+        <location filename="../../mainwindow.ui" line="185"/>
         <source>&amp;Save</source>
         <translation>&amp;Enregistrer</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="186"/>
+        <location filename="../../mainwindow.ui" line="188"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="196"/>
+        <location filename="../../mainwindow.ui" line="198"/>
         <source>Save &amp;As</source>
         <translation>Enregistrer &amp;sous</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="199"/>
+        <location filename="../../mainwindow.ui" line="201"/>
         <source>Ctrl+A</source>
         <translation>Ctrl+A</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="209"/>
+        <location filename="../../mainwindow.ui" line="211"/>
         <source>&amp;Close</source>
         <translation>&amp;Fermer</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="212"/>
+        <location filename="../../mainwindow.ui" line="214"/>
         <source>Ctrl+W</source>
         <translation>Ctrl+W</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="222"/>
+        <location filename="../../mainwindow.ui" line="224"/>
         <source>Zoom &amp;In</source>
         <translation>Zoom a&amp;vant</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="225"/>
+        <location filename="../../mainwindow.ui" line="227"/>
         <source>Ctrl+=</source>
         <translation>Ctrl+=</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="235"/>
+        <location filename="../../mainwindow.ui" line="237"/>
         <source>Zoom &amp;Out</source>
         <translation>Zoom a&amp;rrière</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="238"/>
+        <location filename="../../mainwindow.ui" line="240"/>
         <source>Ctrl+-</source>
         <translation>Ctrl+-</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="248"/>
+        <location filename="../../mainwindow.ui" line="250"/>
         <source>&amp;Copy to Clipboard</source>
         <translation>&amp;Copie vers le presse-papier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="258"/>
-        <location filename="../../mainwindow.ui" line="261"/>
+        <location filename="../../mainwindow.ui" line="260"/>
+        <location filename="../../mainwindow.ui" line="263"/>
         <source>Next File</source>
         <translation>Fichier suivant</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="264"/>
+        <location filename="../../mainwindow.ui" line="266"/>
         <source>PgDown</source>
         <translation>PgDown</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="274"/>
-        <location filename="../../mainwindow.ui" line="277"/>
+        <location filename="../../mainwindow.ui" line="276"/>
+        <location filename="../../mainwindow.ui" line="279"/>
         <source>Previous File</source>
         <translation>Fichier précédent</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="280"/>
+        <location filename="../../mainwindow.ui" line="282"/>
         <source>PgUp</source>
         <translation>PgUp</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="290"/>
+        <location filename="../../mainwindow.ui" line="292"/>
         <source>Original Size</source>
         <translation>Taille d&apos;origine</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="293"/>
+        <location filename="../../mainwindow.ui" line="295"/>
         <source>Ctrl+0</source>
         <translation>Ctrl+0</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="303"/>
+        <location filename="../../mainwindow.ui" line="305"/>
         <source>&amp;Fit</source>
         <translation>Adapter la &amp;taille</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="313"/>
+        <location filename="../../mainwindow.ui" line="315"/>
         <source>&amp;Rotate Clockwise</source>
         <translation>&amp;Rotation horaire</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="323"/>
+        <location filename="../../mainwindow.ui" line="325"/>
         <source>Rotate &amp;Counterclockwise</source>
         <translation>Rotation &amp;anti-horaire</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="328"/>
+        <location filename="../../mainwindow.ui" line="330"/>
         <source>P&amp;references</source>
         <translation>&amp;Préférences</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="333"/>
+        <location filename="../../mainwindow.ui" line="335"/>
         <source>&amp;Print</source>
         <translation>&amp;Imprimer</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="336"/>
+        <location filename="../../mainwindow.ui" line="338"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="346"/>
+        <location filename="../../mainwindow.ui" line="348"/>
         <source>First File</source>
         <translation>Premier fichier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="349"/>
+        <location filename="../../mainwindow.ui" line="351"/>
         <source>Home</source>
         <translation>Début</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="359"/>
+        <location filename="../../mainwindow.ui" line="361"/>
         <source>Last File</source>
         <translation>Dernier fichier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="362"/>
+        <location filename="../../mainwindow.ui" line="364"/>
         <source>End</source>
         <translation>Fin</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="372"/>
+        <location filename="../../mainwindow.ui" line="374"/>
         <source>&amp;New Window</source>
         <translation>&amp;Nouvelle fenêtre</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="375"/>
+        <location filename="../../mainwindow.ui" line="377"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="380"/>
+        <location filename="../../mainwindow.ui" line="382"/>
         <source>Flip &amp;Horizontally</source>
         <translation>Retournement &amp;horizontal</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="390"/>
+        <location filename="../../mainwindow.ui" line="392"/>
         <source>Capture Screenshot</source>
         <translation>Capture d&apos;écran</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="398"/>
+        <location filename="../../mainwindow.ui" line="400"/>
         <source>F&amp;ull Screen</source>
         <translation>&amp;Plein écran</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="401"/>
+        <location filename="../../mainwindow.ui" line="403"/>
         <source>F11</source>
         <translation>F11</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="406"/>
+        <location filename="../../mainwindow.ui" line="408"/>
         <source>Flip &amp;Vertically</source>
         <translation>Retournement &amp;vertical</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="416"/>
+        <location filename="../../mainwindow.ui" line="418"/>
         <source>&amp;Paste from Clipboard</source>
         <translation>&amp;Coller depuis le presse-papier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="429"/>
+        <location filename="../../mainwindow.ui" line="431"/>
         <source>&amp;Slide Show</source>
         <translation>&amp;Diaporama</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="439"/>
+        <location filename="../../mainwindow.ui" line="441"/>
         <source>&amp;Delete</source>
         <translation>&amp;Supprimer</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="442"/>
+        <location filename="../../mainwindow.ui" line="444"/>
         <source>Del</source>
         <translation>Suppr</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="450"/>
+        <location filename="../../mainwindow.ui" line="452"/>
         <source>Show Thumbnails</source>
         <translation>Afficher les miniatures</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="455"/>
+        <location filename="../../mainwindow.ui" line="457"/>
         <source>File Properties</source>
         <translation>Propriétés du fichier</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="463"/>
+        <location filename="../../mainwindow.ui" line="465"/>
         <source>Open &amp;Directory</source>
         <translation>Ouvrir &amp;répertoire</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="466"/>
+        <location filename="../../mainwindow.ui" line="468"/>
         <source>Ctrl+D</source>
         <translation>Ctrl+D</translation>
     </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="476"/>
+        <source>Upload</source>
+        <translation>Envoyer</translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="479"/>
+        <source>Upload the image</source>
+        <translation>Envoyer l&apos;image</translation>
+    </message>
 </context>
 <context>
     <name>PreferencesDialog</name>
@@ -413,7 +472,7 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     <message>
         <location filename="../../screenshotdialog.ui" line="57"/>
         <source>Capture an area of the screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Capturer une zone de l&quot;écran</translation>
     </message>
     <message>
         <location filename="../../screenshotdialog.ui" line="67"/>
@@ -436,4 +495,12 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <translation>Inclurela barre de titre et le cadre</translation>
     </message>
 </context>
+<context>
+    <name>UploadDialog</name>
+    <message>
+        <location filename="../../upload/uploaddialog.ui" line="14"/>
+        <source>Upload</source>
+        <translation>Envoyer</translation>
+    </message>
+</context>
 </TS>
