@@ -16,17 +16,17 @@
     <message>
         <location filename="../../../brightnesssettings.ui" line="35"/>
         <source>Require confirmation after settings change</source>
-        <translation type="unfinished"></translation>
+        <translation>Απαιτείται επιβεβαίωση μετά από τις αλλαγές των ρυθμίσεων</translation>
     </message>
     <message>
         <location filename="../../../brightnesssettings.cpp" line="68"/>
         <source>Brightness settings changed</source>
-        <translation type="unfinished"></translation>
+        <translation>Οι ρυθμίσεις φωτεινότητας τροποποιήθηκαν</translation>
     </message>
     <message>
         <location filename="../../../brightnesssettings.cpp" line="69"/>
         <source>Confirmation required. Are the settings correct?</source>
-        <translation type="unfinished"></translation>
+        <translation>Απαιτείται επιβεβαίωση. Οι ρυθμίσεις είναι σωστές;</translation>
     </message>
 </context>
 <context>
@@ -40,5 +40,10 @@
         <source>&lt;b&gt;Output:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Έξοδος:&lt;/b&gt;</translation>
     </message>
+    <message>
+        <location filename="../../../outputwidget.ui" line="67"/>
+        <source>Right click to reset</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
