@@ -40,5 +40,10 @@
         <source>&lt;b&gt;Output:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Вивід:&lt;/b&gt;</translation>
     </message>
+    <message>
+        <location filename="../../../outputwidget.ui" line="67"/>
+        <source>Right click to reset</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
