@@ -73,14 +73,10 @@
         <source>Format Settings Changed</source>
         <translation>Paramètres du format modifiés</translation>
     </message>
-    <message>
-        <source>Save the settings ? (they will take effect the next time you log in)</source>
-        <translation type="vanished">Enregistrer les modifications (elle seront effective à la prochaine connexion)</translation>
-    </message>
     <message>
         <location filename="../../../localeconfig.cpp" line="309"/>
         <source>Do you want to save your changes? They will take effect the next time you log in.</source>
-        <translation type="unfinished"></translation>
+        <translation>Voulez-vous enregistrer vos modifications ? Elles prendront effet à votre prochaine connexion.</translation>
     </message>
     <message>
         <location filename="../../../localeconfig.cpp" line="430"/>
