@@ -260,7 +260,7 @@
         <translation>Omvendt</translation>
     </message>
     <message>
-        <location filename="../../../monitorwidget.cpp" line="254"/>
+        <location filename="../../../monitorwidget.cpp" line="255"/>
         <source>%1 Hz</source>
         <translation>%1 Hz</translation>
     </message>
@@ -283,7 +283,7 @@
     <message>
         <location filename="../../../timeoutdialog.ui" line="46"/>
         <source>Are the current settings OK for you?</source>
-        <translation>Er de aktuelle indstillinger OK for dig?</translation>
+        <translation>Er de nuværende indstillinger OK for dig?</translation>
     </message>
     <message numerus="yes">
         <location filename="../../../timeoutdialog.cpp" line="62"/>
