@@ -228,28 +228,28 @@
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="250"/>
         <source>A&amp;uto-hide</source>
-        <translation type="unfinished"></translation>
+        <translation>Αυ&amp;τόματη απόκρυψη</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="301"/>
         <location filename="../../../config/configpanelwidget.ui" line="311"/>
         <source>Zero means no delay</source>
-        <translation type="unfinished"></translation>
+        <translation>Μηδέν σημαίνει χωρίς καθυστέρηση</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="304"/>
         <source>Show with delay:</source>
-        <translation type="unfinished"></translation>
+        <translation>Εμφάνιση με καθυστέρηση:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="330"/>
         <source>Don&apos;t allow maximized windows go under the panel window</source>
-        <translation type="unfinished"></translation>
+        <translation>Να μην επιτρέπεται στα μεγιστοποιημένα παράθυρα να καταλαμβάνουν τον χώρο κάτω από το πλαίσιο του πίνακα</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="333"/>
         <source>Reserve space on display</source>
-        <translation type="unfinished"></translation>
+        <translation>Δέσμευση χώρου στην απεικόνιση</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="349"/>
@@ -436,45 +436,45 @@
         <translation type="vanished">Προσθήκη γραφικών συστατικών του πίνακα</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1066"/>
-        <location filename="../../../lxqtpanel.cpp" line="1091"/>
+        <location filename="../../../lxqtpanel.cpp" line="1068"/>
+        <location filename="../../../lxqtpanel.cpp" line="1094"/>
         <source>Panel</source>
         <translation>Πίνακας</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1094"/>
+        <location filename="../../../lxqtpanel.cpp" line="1097"/>
         <source>Configure Panel</source>
         <translation>Διαμόρφωση του πίνακα</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1099"/>
+        <location filename="../../../lxqtpanel.cpp" line="1102"/>
         <source>Manage Widgets</source>
         <translation>Διαχείριση των γραφικών συστατικών</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1105"/>
+        <location filename="../../../lxqtpanel.cpp" line="1108"/>
         <source>Add New Panel</source>
         <translation>Προσθήκη νέου πίνακα</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1112"/>
+        <location filename="../../../lxqtpanel.cpp" line="1115"/>
         <source>Remove Panel</source>
         <comment>Menu Item</comment>
-        <translation type="unfinished">Αφαίρεση πίνακα</translation>
+        <translation>Αφαίρεση πίνακα</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1117"/>
+        <location filename="../../../lxqtpanel.cpp" line="1120"/>
         <source>Lock This Panel</source>
         <translation>Κλείδωμα του πίνακα</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1259"/>
+        <location filename="../../../lxqtpanel.cpp" line="1265"/>
         <source>Remove Panel</source>
         <comment>Dialog Title</comment>
-        <translation type="unfinished">Αφαίρεση πίνακα</translation>
+        <translation>Αφαίρεση πίνακα</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1260"/>
+        <location filename="../../../lxqtpanel.cpp" line="1266"/>
         <source>Removing a panel can not be undone.
 Do you want to remove this panel?</source>
         <translation>Η αφαίρεση ενός πίνακα δεν μπορεί να αναιρεθεί.
