@@ -6,27 +6,27 @@
     <message>
         <location filename="../../../config/addplugindialog.ui" line="14"/>
         <source>Add Plugins</source>
-        <translation type="unfinished"></translation>
+        <translation>添加插件</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.ui" line="22"/>
         <source>Search:</source>
-        <translation type="unfinished"></translation>
+        <translation>搜索:</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.ui" line="98"/>
         <source>Add Widget</source>
-        <translation type="unfinished"></translation>
+        <translation>添加小部件</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.ui" line="105"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>关闭</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.cpp" line="115"/>
         <source>(only one instance can run at a time)</source>
-        <translation type="unfinished"></translation>
+        <translation>（一次只能运行一个替代项）</translation>
     </message>
 </context>
 <context>
@@ -118,17 +118,17 @@
     <message>
         <location filename="../../../config/configpaneldialog.cpp" line="31"/>
         <source>Configure Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>配置面板</translation>
     </message>
     <message>
         <location filename="../../../config/configpaneldialog.cpp" line="38"/>
         <source>Panel</source>
-        <translation type="unfinished">qxkb</translation>
+        <translation>面板</translation>
     </message>
     <message>
         <location filename="../../../config/configpaneldialog.cpp" line="42"/>
         <source>Widgets</source>
-        <translation type="unfinished"></translation>
+        <translation>小部件</translation>
     </message>
 </context>
 <context>
@@ -136,226 +136,226 @@
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="20"/>
         <source>Configure panel</source>
-        <translation type="unfinished">配置面板</translation>
+        <translation>配置面板</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="44"/>
         <source>Size</source>
-        <translation type="unfinished"></translation>
+        <translation>大小</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="81"/>
         <source>Size:</source>
-        <translation type="unfinished">大小：</translation>
+        <translation>大小:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="109"/>
         <location filename="../../../config/configpanelwidget.ui" line="153"/>
         <source> px</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="166"/>
         <source>Icon size:</source>
-        <translation type="unfinished"></translation>
+        <translation>图标大小:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="88"/>
         <source>Length:</source>
-        <translation type="unfinished">长度：</translation>
+        <translation>长度:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="68"/>
         <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;p&gt;如设置长度为负数，则面板长度会等于最大长度加上输入值&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;例：如“长度”设置为-100px，且最大长度为1000px，则实际显示长度为900px。&lt;/i&gt;&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="96"/>
         <source>%</source>
-        <translation type="unfinished">%</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="101"/>
         <source>px</source>
-        <translation type="unfinished">px</translation>
+        <translation>px</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="173"/>
         <source>Rows count:</source>
-        <translation type="unfinished"></translation>
+        <translation>行数:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="202"/>
         <source>Alignment &amp;&amp; position</source>
-        <translation type="unfinished"></translation>
+        <translation>对齐与位置</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="262"/>
         <location filename="../../../config/configpanelwidget.ui" line="285"/>
         <source>Zero means no animation</source>
-        <translation type="unfinished"></translation>
+        <translation>如设置为0，则不显示动画</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="288"/>
         <location filename="../../../config/configpanelwidget.ui" line="314"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="265"/>
         <source>Animation duration:</source>
-        <translation type="unfinished"></translation>
+        <translation>动画时间:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="219"/>
         <location filename="../../../config/configpanelwidget.cpp" line="202"/>
         <source>Left</source>
-        <translation type="unfinished">左</translation>
+        <translation>左</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="224"/>
         <location filename="../../../config/configpanelwidget.cpp" line="203"/>
         <location filename="../../../config/configpanelwidget.cpp" line="209"/>
         <source>Center</source>
-        <translation type="unfinished">居中</translation>
+        <translation>居中</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="229"/>
         <location filename="../../../config/configpanelwidget.cpp" line="204"/>
         <source>Right</source>
-        <translation type="unfinished">右</translation>
+        <translation>右</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="250"/>
         <source>A&amp;uto-hide</source>
-        <translation type="unfinished"></translation>
+        <translation>自动隐藏(&amp;U)</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="301"/>
         <location filename="../../../config/configpanelwidget.ui" line="311"/>
         <source>Zero means no delay</source>
-        <translation type="unfinished"></translation>
+        <translation>如设置为0，则无延迟</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="304"/>
         <source>Show with delay:</source>
-        <translation type="unfinished"></translation>
+        <translation>动画延迟:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="330"/>
         <source>Don&apos;t allow maximized windows go under the panel window</source>
-        <translation type="unfinished"></translation>
+        <translation>不允许最大化窗口显示在面板窗口之下</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="333"/>
         <source>Reserve space on display</source>
-        <translation type="unfinished"></translation>
+        <translation>显示器上的保留空间</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="349"/>
         <source>Custom styling</source>
-        <translation type="unfinished"></translation>
+        <translation>自定义样式</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="370"/>
         <source>Font color:</source>
-        <translation type="unfinished"></translation>
+        <translation>字体颜色:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="410"/>
         <source>Background color:</source>
-        <translation type="unfinished"></translation>
+        <translation>背景颜色:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="449"/>
         <source>Background opacity:</source>
-        <translation type="unfinished"></translation>
+        <translation>背景不透明度:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="481"/>
         <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;small&gt;必须要启用合成特效才可以使面板透明&lt;/small&gt;</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="509"/>
         <source>Background image:</source>
-        <translation type="unfinished"></translation>
+        <translation>背景图像:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="208"/>
         <source>Alignment:</source>
-        <translation type="unfinished">对齐：</translation>
+        <translation>对齐:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="237"/>
         <source>Position:</source>
-        <translation type="unfinished">位置：</translation>
+        <translation>位置:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="168"/>
         <source>Top of desktop</source>
-        <translation type="unfinished">桌面顶部</translation>
+        <translation>桌面顶部</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="169"/>
         <source>Left of desktop</source>
-        <translation type="unfinished">桌面左侧</translation>
+        <translation>桌面左侧</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="170"/>
         <source>Right of desktop</source>
-        <translation type="unfinished">桌面右侧</translation>
+        <translation>桌面右侧</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="171"/>
         <source>Bottom of desktop</source>
-        <translation type="unfinished">桌面底部</translation>
+        <translation>桌面底部</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="180"/>
         <source>Top of desktop %1</source>
-        <translation type="unfinished">桌面顶部 %1</translation>
+        <translation>桌面顶部 %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="181"/>
         <source>Left of desktop %1</source>
-        <translation type="unfinished">桌面左侧 %1</translation>
+        <translation>桌面左侧 %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="182"/>
         <source>Right of desktop %1</source>
-        <translation type="unfinished">左面右侧 %1</translation>
+        <translation>左面右侧 %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="183"/>
         <source>Bottom of desktop %1</source>
-        <translation type="unfinished">桌面底部 %1</translation>
+        <translation>桌面底部 %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="208"/>
         <source>Top</source>
-        <translation type="unfinished"></translation>
+        <translation>顶部</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="210"/>
         <source>Bottom</source>
-        <translation type="unfinished"></translation>
+        <translation>底部</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="368"/>
         <location filename="../../../config/configpanelwidget.cpp" line="384"/>
         <source>Pick color</source>
-        <translation type="unfinished"></translation>
+        <translation>选择颜色</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="402"/>
         <source>Images (*.png *.gif *.jpg)</source>
-        <translation type="unfinished"></translation>
+        <translation>图像 (*.png *.gif *.jpg)</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="402"/>
         <source>Pick image</source>
-        <translation type="unfinished"></translation>
+        <translation>选择图像</translation>
     </message>
 </context>
 <context>
@@ -363,17 +363,17 @@
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="14"/>
         <source>Configure Plugins</source>
-        <translation type="unfinished"></translation>
+        <translation>配置插件</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="84"/>
         <source>Note: changes made in this page cannot be reset.</source>
-        <translation type="unfinished"></translation>
+        <translation>注：在此页更改的设置无法重置。</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="112"/>
         <source>Move up</source>
-        <translation type="unfinished"></translation>
+        <translation>上移</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="115"/>
@@ -382,74 +382,75 @@
         <location filename="../../../config/configpluginswidget.ui" line="164"/>
         <location filename="../../../config/configpluginswidget.ui" line="185"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="126"/>
         <source>Move down</source>
-        <translation type="unfinished"></translation>
+        <translation>下移</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="147"/>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>添加</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="161"/>
         <source>Remove</source>
-        <translation type="unfinished">删除</translation>
+        <translation>删除</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="182"/>
         <source>Configure</source>
-        <translation type="unfinished">配置</translation>
+        <translation>配置</translation>
     </message>
 </context>
 <context>
     <name>LXQtPanel</name>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1066"/>
-        <location filename="../../../lxqtpanel.cpp" line="1091"/>
-        <source>Panel</source>
-        <translation>qxkb</translation>
-    </message>
-    <message>
+        <location filename="../../../lxqtpanel.cpp" line="1068"/>
         <location filename="../../../lxqtpanel.cpp" line="1094"/>
+        <source>Panel</source>
+        <translation>面板</translation>
+    </message>
+    <message>
+        <location filename="../../../lxqtpanel.cpp" line="1097"/>
         <source>Configure Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>配置面板</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1099"/>
+        <location filename="../../../lxqtpanel.cpp" line="1102"/>
         <source>Manage Widgets</source>
-        <translation type="unfinished"></translation>
+        <translation>管理小部件</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1105"/>
+        <location filename="../../../lxqtpanel.cpp" line="1108"/>
         <source>Add New Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>新增面板</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1112"/>
+        <location filename="../../../lxqtpanel.cpp" line="1115"/>
         <source>Remove Panel</source>
         <comment>Menu Item</comment>
-        <translation type="unfinished"></translation>
+        <translation>删除面板</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1117"/>
+        <location filename="../../../lxqtpanel.cpp" line="1120"/>
         <source>Lock This Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>锁定此面板</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1259"/>
+        <location filename="../../../lxqtpanel.cpp" line="1265"/>
         <source>Remove Panel</source>
         <comment>Dialog Title</comment>
-        <translation type="unfinished"></translation>
+        <translation>删除面板</translation>
     </message>
     <message>
-        <location filename="../../../lxqtpanel.cpp" line="1260"/>
+        <location filename="../../../lxqtpanel.cpp" line="1266"/>
         <source>Removing a panel can not be undone.
 Do you want to remove this panel?</source>
-        <translation type="unfinished"></translation>
+        <translation>删除面板不可撤销。
+是否确认要删除此面板？</translation>
     </message>
     <message>
         <source>Configure panel...</source>
@@ -487,17 +488,17 @@ Do you want to remove this panel?</source>
     <message>
         <location filename="../../../plugin.cpp" line="416"/>
         <source>Configure &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>配置“%1”</translation>
     </message>
     <message>
         <location filename="../../../plugin.cpp" line="421"/>
         <source>Move &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>移动“%1”</translation>
     </message>
     <message>
         <location filename="../../../plugin.cpp" line="429"/>
         <source>Remove &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>删除“%1”</translation>
     </message>
 </context>
 <context>
@@ -505,12 +506,12 @@ Do you want to remove this panel?</source>
     <message>
         <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
         <source>Use alternate configuration file.</source>
-        <translation type="unfinished"></translation>
+        <translation>使用另一个配置文件。</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
         <source>Configuration file</source>
-        <translation type="unfinished"></translation>
+        <translation>配置文件</translation>
     </message>
 </context>
 </TS>
