@@ -4,20 +4,21 @@
 <context>
     <name>LXQtQuickLaunch</name>
     <message>
-        <location filename="../../../lxqtquicklaunch.cpp" line="213"/>
+        <location filename="../../../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
         <translation>Error al soltar</translation>
     </message>
     <message>
-        <location filename="../../../lxqtquicklaunch.cpp" line="214"/>
+        <location filename="../../../lxqtquicklaunch.cpp" line="215"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
-        <translation>El archivo/URL &apos;%1&apos; por el momento no puede incrustarse en QuickLaunch</translation>
+        <translation>El archivo/URL &apos;%1&apos; no puede incrustarse de momento en QuickLaunch</translation>
     </message>
     <message>
-        <location filename="../../../lxqtquicklaunch.cpp" line="320"/>
+        <location filename="../../../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
-        <translation type="unfinished"></translation>
+        <translation>Soltar iconos de
+aplicaciones aquí</translation>
     </message>
 </context>
 <context>
@@ -35,7 +36,7 @@ icons here</source>
     <message>
         <location filename="../../../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
-        <translation>Quitar de quicklaunch</translation>
+        <translation>Quitar del lanzador rápido</translation>
     </message>
 </context>
 </TS>
