@@ -4,7 +4,7 @@
 <context>
     <name>LXQtTaskBar</name>
     <message>
-        <location filename="../../../lxqttaskbar.cpp" line="641"/>
+        <location filename="../../../lxqttaskbar.cpp" line="644"/>
         <source>Activate task %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -12,87 +12,97 @@
 <context>
     <name>LXQtTaskButton</name>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="478"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
         <source>Application</source>
         <translation>التّطبيق</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="512"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
         <source>To &amp;Desktop</source>
         <translation>إلى س&amp;طح المكتب</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
         <source>&amp;All Desktops</source>
         <translation>&amp;كلّ أسطح المكتب</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="522"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
         <source>Desktop &amp;%1</source>
         <translation>سطح المكتب &amp;%1</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="529"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
         <source>&amp;To Current Desktop</source>
         <translation>إ&amp;لى سطح المكتب الحاليّ</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="538"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
+        <source>&amp;Move</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
+        <source>Resi&amp;ze</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
         <source>Ma&amp;ximize</source>
         <translation>ك&amp;بّر</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
         <source>Maximize vertically</source>
         <translation>كبّر رأسيًّا</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
         <source>Maximize horizontally</source>
         <translation>كبّر أفقيًّا</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="556"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
         <source>&amp;Restore</source>
         <translation>ا&amp;ستعد</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="560"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
         <source>Mi&amp;nimize</source>
         <translation>&amp;صغّر</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="566"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
         <source>Roll down</source>
         <translation>لُفّ لأسفل</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="572"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
         <source>Roll up</source>
         <translation>لُفّ لأعلى</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="580"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
         <source>&amp;Layer</source>
         <translation>ال&amp;طّبقة</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="582"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
         <source>Always on &amp;top</source>
         <translation>&amp;فوق الكلّ دائمًا</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="588"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
         <source>&amp;Normal</source>
         <translation>&amp;عاديّ</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="594"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
         <source>Always on &amp;bottom</source>
         <translation>&amp;تحت الكلّ دائمًا</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="602"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
         <source>&amp;Close</source>
         <translation>أ&amp;غلق</translation>
     </message>
