@@ -4,95 +4,105 @@
 <context>
     <name>LXQtTaskBar</name>
     <message>
-        <location filename="../../../lxqttaskbar.cpp" line="641"/>
+        <location filename="../../../lxqttaskbar.cpp" line="644"/>
         <source>Activate task %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Ativar tarefa %1</translation>
     </message>
 </context>
 <context>
     <name>LXQtTaskButton</name>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="478"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
         <source>Application</source>
         <translation>Aplicação</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="512"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
         <source>To &amp;Desktop</source>
         <translation>Na área &amp;de trabalho</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
         <source>&amp;All Desktops</source>
         <translation>Tod&amp;as as áreas de trabalho</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="522"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
         <source>Desktop &amp;%1</source>
         <translation>Área de trabalho &amp;%1</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="529"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
         <source>&amp;To Current Desktop</source>
         <translation>Na área de &amp;trabalho atual</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="538"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
+        <source>&amp;Move</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
+        <source>Resi&amp;ze</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
         <source>Ma&amp;ximize</source>
         <translation>Ma&amp;ximizar</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
         <source>Maximize vertically</source>
         <translation>Maximizar na vertical</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
         <source>Maximize horizontally</source>
         <translation>Maximizar na horizontal</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="556"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
         <source>&amp;Restore</source>
         <translation>&amp;Restaurar</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="560"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
         <source>Mi&amp;nimize</source>
         <translation>Mi&amp;nimizar</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="566"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
         <source>Roll down</source>
         <translation>Desenrolar</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="572"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
         <source>Roll up</source>
         <translation>Enrolar</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="580"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
         <source>&amp;Layer</source>
         <translation>Ca&amp;mada</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="582"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
         <source>Always on &amp;top</source>
         <translation>Sempre na &amp;frente</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="588"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
         <source>&amp;Normal</source>
         <translation>&amp;Normal</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="594"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
         <source>Always on &amp;bottom</source>
         <translation>Sempr&amp;e por trás</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="602"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
         <source>&amp;Close</source>
         <translation>Fe&amp;char</translation>
     </message>
@@ -153,7 +163,7 @@
     <message>
         <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
         <source>Cycle windows on wheel scrolling</source>
-        <translation type="unfinished"></translation>
+        <translation>Percorrer janelas com a roda do rato</translation>
     </message>
     <message>
         <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
@@ -163,7 +173,7 @@
     <message>
         <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
         <source>Show popup on mouse hover</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar janela ao passar com o rato</translation>
     </message>
     <message>
         <source>Show popup on mouse hover </source>
