@@ -4,7 +4,7 @@
 <context>
     <name>LXQtTaskBar</name>
     <message>
-        <location filename="../../../lxqttaskbar.cpp" line="641"/>
+        <location filename="../../../lxqttaskbar.cpp" line="644"/>
         <source>Activate task %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -12,87 +12,97 @@
 <context>
     <name>LXQtTaskButton</name>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="478"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
         <source>Application</source>
         <translation>Приложение</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="512"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
         <source>To &amp;Desktop</source>
         <translation>&amp;На рабочий стол</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
         <source>&amp;All Desktops</source>
         <translation>&amp;Все рабочие столы</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="522"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
         <source>Desktop &amp;%1</source>
         <translation>Рабочий стол &amp;%1</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="529"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
         <source>&amp;To Current Desktop</source>
         <translation>На &amp;текущий рабочий стол</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="538"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
+        <source>&amp;Move</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
+        <source>Resi&amp;ze</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
         <source>Ma&amp;ximize</source>
         <translation>Р&amp;азвернуть</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
         <source>Maximize vertically</source>
         <translation>Развернуть по вертикали</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
         <source>Maximize horizontally</source>
         <translation>Развернуть по горизонтали</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="556"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
         <source>&amp;Restore</source>
         <translation>&amp;Восстановить</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="560"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
         <source>Mi&amp;nimize</source>
         <translation>&amp;Свернуть</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="566"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
         <source>Roll down</source>
         <translation>Развернуть из заголовока</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="572"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
         <source>Roll up</source>
         <translation>Свернуть в заголовок</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="580"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
         <source>&amp;Layer</source>
         <translation>&amp;Положение</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="582"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
         <source>Always on &amp;top</source>
         <translation>Всегда на&amp;верху</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="588"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
         <source>&amp;Normal</source>
         <translation>&amp;Обычное</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="594"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
         <source>Always on &amp;bottom</source>
         <translation>Всегда в&amp;низу</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="602"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
         <source>&amp;Close</source>
         <translation>&amp;Закрыть</translation>
     </message>
