@@ -26,12 +26,16 @@
     <message>
         <location filename="../../../lxqtvolume.cpp" line="287"/>
         <source>Volume: muted</source>
-        <translation type="unfinished"></translation>
+        <translation>音量: ミュートされています</translation>
     </message>
     <message>
         <location filename="../../../lxqtvolume.cpp" line="289"/>
+        <source>Volume: %1%</source>
+        <translation type="unfinished">音量: %1%</translation>
+    </message>
+    <message>
         <source>Volume: %1</source>
-        <translation>音量: %1</translation>
+        <translation type="vanished">音量: %1</translation>
     </message>
 </context>
 <context>
@@ -84,7 +88,7 @@
     <message>
         <location filename="../../../lxqtvolumeconfiguration.ui" line="84"/>
         <source>Always notify about volume changes</source>
-        <translation type="unfinished"></translation>
+        <translation>音量の変更時には常に通知する</translation>
     </message>
     <message>
         <location filename="../../../lxqtvolumeconfiguration.ui" line="99"/>
@@ -107,7 +111,7 @@
     <message>
         <location filename="../../../volumepopup.cpp" line="55"/>
         <source>Mi&amp;xer</source>
-        <translation type="unfinished"></translation>
+        <translation>ミキサー(&amp;x)</translation>
     </message>
     <message>
         <source>Mixer</source>
