@@ -213,5 +213,10 @@
         <source>Shutdown</source>
         <translation>Arrêter</translation>
     </message>
+    <message>
+        <location filename="../../../helpers.cpp" line="40"/>
+        <source>Turn Off monitor(s)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
