@@ -306,25 +306,25 @@
     <message numerus="yes">
         <location filename="../../../batterywatcher.cpp" line="125"/>
         <source>Suspending in %n second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Αναστολή σε %n δευτερόλεπτο(α)</numerusform>
+            <numerusform>Αναστολή σε %n δευτερόλεπτο(α)</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../../../batterywatcher.cpp" line="128"/>
         <source>Hibernating in %n second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Νάρκωση σε %n δευτερόλεπτο(α)</numerusform>
+            <numerusform>Νάρκωση σε %n δευτερόλεπτο(α)</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../../../batterywatcher.cpp" line="131"/>
         <source>Shutting down in %n second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Τερματισμός σε %n δευτερόλεπτο(α)</numerusform>
+            <numerusform>Τερματισμός σε %n δευτερόλεπτο(α)</numerusform>
         </translation>
     </message>
     <message>
@@ -374,12 +374,12 @@
 <context>
     <name>PowerManagementd</name>
     <message>
-        <location filename="../../../powermanagementd.cpp" line="108"/>
+        <location filename="../../../powermanagementd.cpp" line="110"/>
         <source>Power Management</source>
         <translation>Διαχείριση ενέργειας</translation>
     </message>
     <message>
-        <location filename="../../../powermanagementd.cpp" line="109"/>
+        <location filename="../../../powermanagementd.cpp" line="111"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
         <translation>Εκτελείτε την διαχείριση ενέργειας του LXQt για πρώτη φορά.
@@ -387,7 +387,7 @@ You can configure it from settings... </source>
 </translation>
     </message>
     <message>
-        <location filename="../../../powermanagementd.cpp" line="110"/>
+        <location filename="../../../powermanagementd.cpp" line="112"/>
         <source>Configure...</source>
         <translation>Διαμόρφωση...</translation>
     </message>
