@@ -222,53 +222,22 @@
         </translation>
     </message>
 </context>
-<context>
-    <name>IdlenessWatcher</name>
-    <message>
-        <source>LXQt Idleness watcher failed to start</source>
-        <translation type="vanished">Le contrôleur d&apos;activité de LXQt n&apos;a pas pu démarrer</translation>
-    </message>
-    <message>
-        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
-        <translation type="vanished">Interface DBus de org.freedesktop. L&apos;économiseur d&apos;écran est déjà enregistré</translation>
-    </message>
-    <message>
-        <source>The X11 Screensaver extension is not usable</source>
-        <translation type="vanished">L&apos;extension X11 Screensaver n&apos;est pas utilisable</translation>
-    </message>
-    <message>
-        <source>Configure...</source>
-        <translation type="vanished">Configuration ...</translation>
-    </message>
-    <message>
-        <source>ERROR: Screen unlocked</source>
-        <translation type="vanished">ERREUR : écran non verrouillé</translation>
-    </message>
-    <message>
-        <source>Locking program &quot;%1&quot; exited with error code %2</source>
-        <translation type="vanished">Sortie du programme de verrouillage &quot;%1&quot; avec code erreur %2</translation>
-    </message>
-    <message>
-        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
-        <translation type="vanished">Plantage du programme de verrouillage &quot;%1&quot; avec code erreur %2</translation>
-    </message>
-</context>
 <context>
     <name>PowerManagementd</name>
     <message>
-        <location filename="../../../powermanagementd.cpp" line="108"/>
+        <location filename="../../../powermanagementd.cpp" line="110"/>
         <source>Power Management</source>
         <translation>Gestion de l&apos;énergie</translation>
     </message>
     <message>
-        <location filename="../../../powermanagementd.cpp" line="109"/>
+        <location filename="../../../powermanagementd.cpp" line="111"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
         <translation>Le programme de gestion d&apos;énergie de LXQt est exécuté pour la première fois.
 Vous pouvez le configurer depuis Configuration ...</translation>
     </message>
     <message>
-        <location filename="../../../powermanagementd.cpp" line="110"/>
+        <location filename="../../../powermanagementd.cpp" line="112"/>
         <source>Configure...</source>
         <translation>Configuration ...</translation>
     </message>
