@@ -120,7 +120,7 @@
     <message>
         <location filename="../../../basicsettings.ui" line="124"/>
         <source>Lock screen before suspending/hibernating</source>
-        <translation type="unfinished"></translation>
+        <translation>Bloquear ecrã antes de suspender/hibernar</translation>
     </message>
     <message>
         <source>Ask confirmation to leave session</source>
