@@ -17,88 +17,88 @@
 <context>
     <name>MainDialog</name>
     <message>
-        <location filename="../../ui_obconf.h" line="1012"/>
+        <location filename="../../ui_obconf.h" line="1044"/>
         <source>Window Manager Preferences</source>
         <translation>Ablakkezelő tulajdonságok</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1017"/>
+        <location filename="../../ui_obconf.h" line="1049"/>
         <source>Theme</source>
         <translation>Téma</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1019"/>
+        <location filename="../../ui_obconf.h" line="1051"/>
         <source>Appearance</source>
         <translation>Megjelenés</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1021"/>
+        <location filename="../../ui_obconf.h" line="1053"/>
         <source>Font</source>
         <translation>Betű</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1023"/>
-        <location filename="../../ui_obconf.h" line="1038"/>
+        <location filename="../../ui_obconf.h" line="1055"/>
+        <location filename="../../ui_obconf.h" line="1070"/>
         <source>Windows</source>
         <translation>Ablakok</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1025"/>
+        <location filename="../../ui_obconf.h" line="1057"/>
         <source>Move &amp; Resize</source>
-        <translation type="unfinished">Mozgatás és átméretezés</translation>
+        <translation>Mozgatás és átméretezés</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1027"/>
+        <location filename="../../ui_obconf.h" line="1059"/>
         <source>Mouse</source>
         <translation>Egér</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1029"/>
+        <location filename="../../ui_obconf.h" line="1061"/>
         <source>Desktops</source>
         <translation>Asztalok</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1031"/>
+        <location filename="../../ui_obconf.h" line="1063"/>
         <source>Margins</source>
         <translation>Margók</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1033"/>
+        <location filename="../../ui_obconf.h" line="1065"/>
         <source>Dock</source>
         <translation>Dokk</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1036"/>
+        <location filename="../../ui_obconf.h" line="1068"/>
         <source>&amp;Install a new theme...</source>
         <translation>ÚJ téma  telep&amp;ítés...</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1037"/>
+        <location filename="../../ui_obconf.h" line="1069"/>
         <source>Create a theme &amp;archive (.obt)...</source>
         <translation>Téma &amp;archívum készítés (.obt)...</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1039"/>
+        <location filename="../../ui_obconf.h" line="1071"/>
         <source>&amp;Windows retain a border when undecorated</source>
         <translation>&amp;Díszítetlen ablakok bekeretezése</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1040"/>
+        <location filename="../../ui_obconf.h" line="1072"/>
         <source>A&amp;nimate iconify and restore</source>
         <translation>Ikonosítás és a visszaállítás &amp;animált</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1041"/>
+        <location filename="../../ui_obconf.h" line="1073"/>
         <source>Window Titles</source>
         <translation>Ablakcímek</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1042"/>
+        <location filename="../../ui_obconf.h" line="1074"/>
         <source>Button order:</source>
         <translation>Gombsorrend:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1043"/>
+        <location filename="../../ui_obconf.h" line="1075"/>
         <source>N: Window icon
 L: Window label (Title)
 I: Iconify (Minimize)
@@ -115,471 +115,471 @@ S: Elrejt (Felgördít)
 D: Állandósít (Minden asztalon van)</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1056"/>
+        <location filename="../../ui_obconf.h" line="1088"/>
         <source>&amp;Active window title: </source>
         <translation>&amp;Aktív ablakcím: </translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1057"/>
+        <location filename="../../ui_obconf.h" line="1089"/>
         <source>&amp;Inactive window title: </source>
         <translation>&amp;Inaktív ablakcím: </translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1058"/>
+        <location filename="../../ui_obconf.h" line="1090"/>
         <source>Menu &amp;header: </source>
-        <translation>Menüfejléc: </translation>
+        <translation>Menüfe&amp;jléc: </translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1059"/>
+        <location filename="../../ui_obconf.h" line="1091"/>
         <source>&amp;Menu Item: </source>
-        <translation>Menüelem: </translation>
+        <translation>&amp;Menüelem: </translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1060"/>
+        <location filename="../../ui_obconf.h" line="1092"/>
         <source>Active &amp;On-screen display: </source>
         <translation>Aktív ké&amp;pernyő: </translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1061"/>
+        <location filename="../../ui_obconf.h" line="1093"/>
         <source>Inactive O&amp;n-screen display: </source>
         <translation>I&amp;naktív képernyő: </translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1062"/>
+        <location filename="../../ui_obconf.h" line="1094"/>
         <source>Focus &amp;new windows when they appear</source>
         <translation>Ú&amp;j ablakra fókuszál</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1063"/>
+        <location filename="../../ui_obconf.h" line="1095"/>
         <source>&amp;Place new windows under the mouse pointer</source>
-        <translation>Új ablak helye az egérmutatónál</translation>
+        <translation>Új ab&amp;lak helye az egérmutatónál</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1064"/>
+        <location filename="../../ui_obconf.h" line="1096"/>
         <source>&amp;Center new windows when they are placed</source>
         <translation>Új ablak &amp;központosítása</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1065"/>
+        <location filename="../../ui_obconf.h" line="1097"/>
         <source>Prefer to place new windows &amp;on:</source>
         <translation>Új ablak&amp;ok elsődleges helye:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1068"/>
+        <location filename="../../ui_obconf.h" line="1098"/>
         <source>All monitors</source>
         <translation>Összes kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1069"/>
+        <location filename="../../ui_obconf.h" line="1099"/>
         <source>The active monitor</source>
         <translation>Aktív kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1070"/>
+        <location filename="../../ui_obconf.h" line="1100"/>
         <source>The monitor with the mouse</source>
         <translation>Egeres kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1071"/>
+        <location filename="../../ui_obconf.h" line="1101"/>
         <source>Primary monitor</source>
         <translation>Elsődleges kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1073"/>
+        <location filename="../../ui_obconf.h" line="1103"/>
         <source>Primary Monitor</source>
         <translation>Elsődleges kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1074"/>
+        <location filename="../../ui_obconf.h" line="1104"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
         <translation>Az elsődleges kijelző az, ahol a kijelzőváltó párbeszédablakok is megjelennek.</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1075"/>
+        <location filename="../../ui_obconf.h" line="1105"/>
         <source>Primary &amp;monitor:</source>
         <translation>El&amp;sődleges kijelző:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1078"/>
+        <location filename="../../ui_obconf.h" line="1106"/>
         <source>Fixed Monitor</source>
         <translation>Fix kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1079"/>
+        <location filename="../../ui_obconf.h" line="1107"/>
         <source>Active Monitor</source>
         <translation>Aktív kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1080"/>
+        <location filename="../../ui_obconf.h" line="1108"/>
         <source>Monitor With Mouse Pointer</source>
         <translation>Egeres kijelző</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1082"/>
+        <location filename="../../ui_obconf.h" line="1110"/>
         <source>&amp;Fixed monitor:</source>
         <translation>&amp;Fix kijelző:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1083"/>
+        <location filename="../../ui_obconf.h" line="1111"/>
         <source>Moving and Resizing Windows</source>
         <translation>Ablakmozgatás és átméretezés</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1084"/>
+        <location filename="../../ui_obconf.h" line="1112"/>
         <source>Update the window contents while &amp;resizing</source>
-        <translation>Ablaktartalom átméretezés alatt frissül</translation>
+        <translation>Ablakta&amp;rtalom átméretezés alatt frissül</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1085"/>
+        <location filename="../../ui_obconf.h" line="1113"/>
         <source>Drag &amp;threshold distance:</source>
-        <translation>Húzási távolság:</translation>
+        <translation>Húzási &amp;távolság:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1086"/>
+        <location filename="../../ui_obconf.h" line="1114"/>
         <source>Amount of resistance against other &amp;windows:</source>
-        <translation type="unfinished">Tá&amp;volság más ablakoktól:</translation>
+        <translation>Tá&amp;volság más ablakoktól:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1087"/>
+        <location filename="../../ui_obconf.h" line="1115"/>
         <source>Amount of resistance against screen &amp;edges:</source>
-        <translation type="unfinished">Távolság a képernyőszél&amp;ekhez:</translation>
+        <translation>Távolság a képernyőszél&amp;ekhez:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1088"/>
+        <location filename="../../ui_obconf.h" line="1116"/>
         <source>&amp;Amount of time to wait before switching:</source>
         <translation>Munkaterületváltási vár&amp;akozás:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1089"/>
+        <location filename="../../ui_obconf.h" line="1117"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
-        <translation>Asztalváltás az ablak képről való kicsúsztatásakor</translation>
+        <translation>A&amp;sztalváltás az ablak képről való kicsúsztatásakor</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1090"/>
+        <location filename="../../ui_obconf.h" line="1118"/>
         <source>Information Dialog</source>
         <translation>Információs párbeszédablak</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1093"/>
-        <location filename="../../ui_obconf.h" line="1100"/>
+        <location filename="../../ui_obconf.h" line="1119"/>
+        <location filename="../../ui_obconf.h" line="1124"/>
         <source>Centered</source>
         <translation>Közepütt</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1094"/>
+        <location filename="../../ui_obconf.h" line="1120"/>
         <source>From left edge</source>
         <translation>Balszéltől</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1095"/>
+        <location filename="../../ui_obconf.h" line="1121"/>
         <source>From right edge</source>
         <translation>Jobbszéltől</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1097"/>
+        <location filename="../../ui_obconf.h" line="1123"/>
         <source>Fixed &amp;y position:</source>
-        <translation>Rögzített y hely:</translation>
+        <translation>Rögzített &amp;y hely:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1101"/>
+        <location filename="../../ui_obconf.h" line="1125"/>
         <source>From top edge</source>
         <translation>Felső széltől</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1102"/>
+        <location filename="../../ui_obconf.h" line="1126"/>
         <source>From bottom edge</source>
         <translation>Alsó széltől</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1104"/>
+        <location filename="../../ui_obconf.h" line="1128"/>
         <source>Information dialog&apos;s &amp;position:</source>
         <translation>Információs &amp;párbeszédablak helye:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1105"/>
+        <location filename="../../ui_obconf.h" line="1129"/>
         <source>Fixed &amp;x position:</source>
-        <translation>Rögzített x hely:</translation>
+        <translation>Rögzített &amp;x hely:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1106"/>
+        <location filename="../../ui_obconf.h" line="1130"/>
         <source>Show &amp;information dialog:</source>
-        <translation>Információs ablak megjelenése:</translation>
+        <translation>&amp;Információs ablak megjelenítése:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1109"/>
+        <location filename="../../ui_obconf.h" line="1131"/>
         <source>When resizing terminal windows</source>
-        <translation type="unfinished">Terminálablak átméretezésekor</translation>
+        <translation>Terminálablak átméretezésekor</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1110"/>
+        <location filename="../../ui_obconf.h" line="1132"/>
         <source>Always</source>
         <translation>Mindig</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1111"/>
+        <location filename="../../ui_obconf.h" line="1133"/>
         <source>Never</source>
         <translation>Soha</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1115"/>
+        <location filename="../../ui_obconf.h" line="1135"/>
         <source>Centered on the window</source>
         <translation>Ablak közepén</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1116"/>
+        <location filename="../../ui_obconf.h" line="1136"/>
         <source>Above the window</source>
         <translation>Ablak felett</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1117"/>
+        <location filename="../../ui_obconf.h" line="1137"/>
         <source>Fixed position on screen</source>
         <translation>A kijelző rögzített helyén</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1119"/>
+        <location filename="../../ui_obconf.h" line="1139"/>
         <source>Focusing Windows</source>
         <translation>Ablakfókusz</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1120"/>
+        <location filename="../../ui_obconf.h" line="1140"/>
         <source>Focus windows when the mouse pointer moves over them</source>
         <translation>Egérmutatóval fókuszál</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1121"/>
+        <location filename="../../ui_obconf.h" line="1141"/>
         <source>&amp;Delay before focusing and raising windows:</source>
-        <translation>Ablakfókusz és kiemelés &amp;késletetése</translation>
+        <translation>Ablakfókusz és kiemelés &amp;késletetése:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1122"/>
+        <location filename="../../ui_obconf.h" line="1142"/>
         <source>Move focus under the mouse when &amp;switching desktops</source>
-        <translation>Asztalváltáskor fókusz az egérmutónál</translation>
+        <translation>A&amp;sztalváltáskor fókusz az egérmutónál</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1123"/>
+        <location filename="../../ui_obconf.h" line="1143"/>
         <source>Move focus &amp;under the mouse when the mouse is not moving</source>
-        <translation>Fókusz az egérhez, ha az mozdulatlan</translation>
+        <translation>Fók&amp;usz az egérhez, ha az mozdulatlan</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1124"/>
+        <location filename="../../ui_obconf.h" line="1144"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
-        <translation>Ablakkiemelés, ha az egérkurzor odamegy</translation>
+        <translation>Ablakkiemelés, ha az egé&amp;rkurzor odamegy</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1125"/>
+        <location filename="../../ui_obconf.h" line="1145"/>
         <source>Titlebar</source>
         <translation>Címsor</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1126"/>
+        <location filename="../../ui_obconf.h" line="1146"/>
         <source>Double click on the &amp;titlebar:</source>
-        <translation>Dupla kattintás a címsorra:</translation>
+        <translation>Dupla ka&amp;ttintás a címsorra:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1129"/>
+        <location filename="../../ui_obconf.h" line="1147"/>
         <source>Maximizes the window</source>
         <translation>Ablak maximalizálás</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1130"/>
+        <location filename="../../ui_obconf.h" line="1148"/>
         <source>Shades the window</source>
         <translation>Ablak eltűntetés</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1132"/>
+        <location filename="../../ui_obconf.h" line="1150"/>
         <source>Double click ti&amp;me:</source>
         <translation>Duplakattintási &amp;idő:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1133"/>
+        <location filename="../../ui_obconf.h" line="1151"/>
         <source>&amp;Show a notification when switching desktops</source>
-        <translation>Asztalváltáskor értesítés</translation>
+        <translation>Asztalváltáskor értesíté&amp;s</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1134"/>
+        <location filename="../../ui_obconf.h" line="1152"/>
         <source>&amp;Amount of time to show the notification for:</source>
-        <translation>Értesítés megjelenési idő: </translation>
+        <translation>&amp;Az értesítés megjelenési ideje:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1135"/>
+        <location filename="../../ui_obconf.h" line="1153"/>
         <source>&amp;Number of desktops: </source>
         <translation>Asztalok szá&amp;ma: </translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1136"/>
+        <location filename="../../ui_obconf.h" line="1154"/>
         <source>&amp;Desktop names:</source>
         <translation>Asztal&amp;nevek:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1137"/>
+        <location filename="../../ui_obconf.h" line="1155"/>
         <source>Desktop Margins</source>
         <translation>Asztalmargók</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1138"/>
+        <location filename="../../ui_obconf.h" line="1156"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
         <translation>Asztali margók foglalt területek a kijelző szélén,az új ablakok ezen belülre kerülnek, a maximalizált ablakok nem lépnek túl rajtuk.</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1139"/>
+        <location filename="../../ui_obconf.h" line="1157"/>
         <source>Left:</source>
         <translation>Bal:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1140"/>
-        <location filename="../../ui_obconf.h" line="1142"/>
-        <location filename="../../ui_obconf.h" line="1144"/>
-        <location filename="../../ui_obconf.h" line="1146"/>
+        <location filename="../../ui_obconf.h" line="1158"/>
+        <location filename="../../ui_obconf.h" line="1160"/>
+        <location filename="../../ui_obconf.h" line="1162"/>
+        <location filename="../../ui_obconf.h" line="1164"/>
         <source>px</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1141"/>
+        <location filename="../../ui_obconf.h" line="1159"/>
         <source>Top:</source>
         <translation>Fenn:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1143"/>
+        <location filename="../../ui_obconf.h" line="1161"/>
         <source>Right:</source>
         <translation>Jobb:</translation>
     </message>
     <message>
-        <location filename="../../ui_obconf.h" line="1145"/>
+        <location filename="../../ui_obconf.h" line="1163"/>
         <source>Bottom:</source>
         <translation>Lenn:</translation>
     </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1147"/>
-        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1148"/>
-        <source>Position</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1149"/>
-        <source>&amp;Position:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1152"/>
-        <source>Top Left</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1153"/>
-        <source>Top</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1154"/>
-        <source>Top Right</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1155"/>
-        <source>Left</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1156"/>
-        <source>Right</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1157"/>
-        <source>Bottom Left</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1158"/>
-        <source>Bottom</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1159"/>
-        <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1160"/>
-        <source>Floating</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1162"/>
-        <source>&amp;Floating position:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1163"/>
-        <source>x</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1164"/>
-        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../ui_obconf.h" line="1165"/>
-        <source>&amp;Orientation: </source>
-        <translation type="unfinished"></translation>
+        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
+        <translation>A dock a &quot;dokkalkalmazások&quot; speciális helye, a dokkalkalmazás futása alatt nem látható.  A dokkalkalmazások olyasfélék, minta az óra, vagy a rendszertálca.</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1166"/>
+        <source>Position</source>
+        <translation>Hely</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1167"/>
+        <source>&amp;Position:</source>
+        <translation>&amp;Hely:</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1168"/>
-        <source>Vertical</source>
-        <translation type="unfinished"></translation>
+        <source>Top Left</source>
+        <translation>Fenn balra</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1169"/>
-        <source>Horizontal</source>
-        <translation type="unfinished"></translation>
+        <source>Top</source>
+        <translation>Fenn</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1170"/>
+        <source>Top Right</source>
+        <translation>Fenn jobbra</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1171"/>
-        <source>Stacking</source>
-        <translation type="unfinished"></translation>
+        <source>Left</source>
+        <translation>Baloldalt</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1172"/>
-        <source>Keep dock &amp;above other windows</source>
-        <translation type="unfinished"></translation>
+        <source>Right</source>
+        <translation>Jobboldalt</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1173"/>
-        <source>A&amp;llow dock to be both above and below windows</source>
-        <translation type="unfinished"></translation>
+        <source>Bottom Left</source>
+        <translation>Lenn balra</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1174"/>
-        <source>Keep dock &amp;below other windows</source>
-        <translation type="unfinished"></translation>
+        <source>Bottom</source>
+        <translation>Lenn</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1175"/>
-        <source>Hiding</source>
-        <translation type="unfinished"></translation>
+        <source>Bottom Right</source>
+        <translation>Lenn jobbra</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1176"/>
-        <source>&amp;Delay before hiding:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../ui_obconf.h" line="1177"/>
-        <source>Delay before &amp;showing:</source>
-        <translation type="unfinished"></translation>
+        <source>Floating</source>
+        <translation>Úszó</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1178"/>
-        <source>&amp;Hide off screen</source>
-        <translation type="unfinished"></translation>
+        <source>&amp;Floating position:</source>
+        <translation>Ú&amp;szó helyzet:</translation>
     </message>
     <message>
         <location filename="../../ui_obconf.h" line="1179"/>
+        <source>x</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1180"/>
+        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
+        <translation>A&amp;z ablakok a dokkoló területén is elhelyezkedhetnek</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1181"/>
+        <source>&amp;Orientation: </source>
+        <translation>I&amp;rány: </translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1182"/>
+        <source>Vertical</source>
+        <translation>Függőleges</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1183"/>
+        <source>Horizontal</source>
+        <translation>Vízszintes</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1185"/>
+        <source>Stacking</source>
+        <translation>Kupacolt</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1186"/>
+        <source>Keep dock &amp;above other windows</source>
+        <translation>A dokk az &amp;ablakok fölött marad</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1187"/>
+        <source>A&amp;llow dock to be both above and below windows</source>
+        <translation>A dokk az ab&amp;lakok előtt és alatt is lehet</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1188"/>
+        <source>Keep dock &amp;below other windows</source>
+        <translation>A dokk az a&amp;blakok alatt marad</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1189"/>
+        <source>Hiding</source>
+        <translation>Elrejtés</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1190"/>
+        <source>&amp;Delay before hiding:</source>
+        <translation>&amp;Elrejtés késleltetése:</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1191"/>
+        <source>Delay before &amp;showing:</source>
+        <translation>Megjelené&amp;si késleltetés:</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1192"/>
+        <source>&amp;Hide off screen</source>
+        <translation>A &amp;képernyőn elrejtés</translation>
+    </message>
+    <message>
+        <location filename="../../ui_obconf.h" line="1193"/>
         <source>About</source>
         <translation>A programról</translation>
     </message>
@@ -622,7 +622,17 @@ The program is based on ObConf developed by the following developers.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Openbox beállító
+
+Copyright (c) 2014-2015
+
+Szerzők:
+* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
+
+A program az ObConf -on alapul, melynek fejlesztői.
+* Dana Jansens &lt;danakj@orodu.net&gt;
+* Tim Riley &lt;tr@slackzone.org&gt;
+* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
     </message>
     <message>
         <source>A preferences manager for Openbox
@@ -749,18 +759,18 @@ Options:
         <translation></translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="225"/>
-        <location filename="../../obconf-qt.cpp" line="241"/>
+        <location filename="../../obconf-qt.cpp" line="227"/>
+        <location filename="../../obconf-qt.cpp" line="243"/>
         <source>Error</source>
         <translation>Hiba</translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="226"/>
+        <location filename="../../obconf-qt.cpp" line="228"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
-        <translation>Nem mtöltgető be rc.xml fájl. Rendesen telepítve van az Openbox?</translation>
+        <translation>Nem mtöltgető be rc.xml fájl. Lehet, hogy nincs rendesen telepítve az Openbox.</translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="239"/>
+        <location filename="../../obconf-qt.cpp" line="241"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
