@@ -30,13 +30,13 @@
         <location filename="../../channel.cc" line="89"/>
         <source>%1% (%2dB)</source>
         <comment>volume slider label [X% (YdB)]</comment>
-        <translation type="unfinished"></translation>
+        <translation>%1% (%2dB)</translation>
     </message>
     <message>
         <location filename="../../channel.cc" line="93"/>
         <source>%1%</source>
         <comment>volume slider label [X%]</comment>
-        <translation type="unfinished"></translation>
+        <translation>%1%</translation>
     </message>
     <message>
         <location filename="../../channel.cc" line="160"/>
@@ -151,14 +151,10 @@
         <source> ms</source>
         <translation> ms</translation>
     </message>
-    <message>
-        <source>Rename Device...</source>
-        <translation type="vanished">Renommer le périphérique ...</translation>
-    </message>
     <message>
         <location filename="../../devicewidget.cc" line="40"/>
         <source>Rename device...</source>
-        <translation type="unfinished"></translation>
+        <translation>Renommer le périphérique...</translation>
     </message>
     <message>
         <location filename="../../devicewidget.cc" line="154"/>
@@ -178,16 +174,12 @@
     <message>
         <location filename="../../devicewidget.cc" line="232"/>
         <source>Rename device %1 to:</source>
-        <translation type="unfinished"></translation>
+        <translation>Renommer le périphérique %1 an :</translation>
     </message>
     <message>
         <location filename="../../devicewidget.cc" line="239"/>
         <source>pa_ext_device_manager_set_device_description() failed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>pa_ext_device_manager_write() failed</source>
-        <translation type="vanished">échec de pa_ext_device_manager_write()</translation>
+        <translation>Echec de pa_ext_device_manager_set_device_description()</translation>
     </message>
 </context>
 <context>
@@ -323,18 +315,6 @@
         <source>...</source>
         <translation>...</translation>
     </message>
-    <message>
-        <source>Error reading config file %s: %s</source>
-        <translation type="vanished">Erreur de lecture du fichier de configuration %s : %s</translation>
-    </message>
-    <message>
-        <source>Error saving preferences</source>
-        <translation type="vanished">Erreur d&apos;enregistrement des préférences</translation>
-    </message>
-    <message>
-        <source>Error writing config file %s</source>
-        <translation type="vanished">Erreur d&apos;écriture du fichier de configuration %s</translation>
-    </message>
     <message>
         <location filename="../../mainwindow.cc" line="159"/>
         <source> (plugged in)</source>
